(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     18541,        597]
NotebookOptionsPosition[     16006,        509]
NotebookOutlinePosition[     16341,        524]
CellTagsIndexPosition[     16298,        521]
WindowFrame->Normal
ContainsDynamic->False*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Calculations", " ", "for", " ", "the", " ", 
    RowBox[{"grooves", "/", "mm"}], " ", "required", " ", "for", " ", "the", 
    " ", "Sr", " ", "wavelengths", " ", "to", " ", "reflect", " ", "from", 
    " ", "grating", " ", 
    RowBox[{"at", " ", "~", "90"}], "\[Degree]"}], " ", "*)"}], 
  " "}]], "Input",
 CellChangeTimes->{{3.465328083747851*^9, 3.4653281310389643`*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"m\[Lambda]", " ", "=", " ", 
   RowBox[{"d", " ", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"sin", 
       RowBox[{"(", "\[Alpha]", ")"}]}], " ", "+", " ", 
      RowBox[{"sin", 
       RowBox[{"(", "\[Beta]", ")"}]}]}], " ", ")"}], " ", "is", " ", "the", 
    " ", "general", " ", "diffraction", " ", "equation", " ", "for", " ", 
    "light", " ", "incident", " ", "at", " ", "an", " ", "angle", " ", 
    "\[Alpha]", " ", 
    RowBox[{"(", 
     RowBox[{
     "\[Beta]", " ", "is", " ", "the", " ", "diffraction", " ", "angle"}], 
     ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465834459281633*^9, 3.465834636977981*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
   "We", " ", "want", " ", "the", " ", "first", " ", "order", " ", "to", " ", 
    "reflect", " ", "back", " ", "into", " ", "the", " ", "beam"}], ",", " ", 
   
   RowBox[{
    RowBox[{"so", " ", "take", " ", "\[Alpha]"}], "=", 
    RowBox[{
     RowBox[{"\[Beta]", " ", "and", " ", "m"}], "=", "1"}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.46583463975716*^9, 3.465834674363907*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Thus", ",", " ", 
   RowBox[{
    RowBox[{"we", " ", "have", " ", "\[Lambda]"}], " ", "=", " ", 
    RowBox[{
     RowBox[{"2", "d", " ", "sin", 
      RowBox[{"(", "\[Alpha]", ")"}], " ", "and", " ", 
      RowBox[{"(", 
       RowBox[{"for", " ", "our", " ", "design"}], ")"}], " ", "\[Alpha]"}], 
     " ", "=", " ", 
     RowBox[{"45", "\[Degree]"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.4658346776767397`*^9, 3.465834765489444*^9}, 
   3.4658451346466208`*^9}],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.4658347703940563`*^9, 3.4658347713848658`*^9}, {
  3.465834844840486*^9, 3.465834845368675*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"For", " ", 
   RowBox[{"prototye", ":", " ", 
    RowBox[{
     RowBox[{"Rb87", ".", " ", "780"}], " ", "nm"}]}]}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.4658348101365147`*^9, 3.465834840806608*^9}, {
  3.465834991411841*^9, 3.4658349944332657`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"10", "^", "6"}], "/", 
   RowBox[{"(", 
    RowBox[{"780", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "4"}], "]"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465834861433709*^9, 3.46583487068055*^9}, {
  3.465834933704459*^9, 3.465834960049388*^9}, {3.465835008413331*^9, 
  3.465835077961548*^9}}],

Cell[BoxData["1813.0943107347373`"], "Output",
 CellChangeTimes->{3.465836100844987*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"We", " ", "used", " ", "1800", " ", 
   RowBox[{"g", "/", "mm"}], " ", "which", " ", "turns", " ", "out", " ", 
   "to", " ", "be", " ", "close", " ", "enough", " ", "to", " ", "a", " ", 
   "total", " ", "reflection", " ", "angle", " ", "of", " ", "90", 
   "\[Degree]"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465835091062529*^9, 3.465835109457355*^9}, {
  3.465836113729879*^9, 3.46583612113488*^9}, {3.4658451387365103`*^9, 
  3.465845140558283*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"780", "*", 
     RowBox[{"1800", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465835335021851*^9, 3.465835350961565*^9}, {
  3.465835865567539*^9, 3.465835868681223*^9}, {3.465835919074883*^9, 
  3.465835963745782*^9}, {3.465836038881398*^9, 3.465836039599625*^9}, {
  3.465836108799073*^9, 3.46583610921796*^9}}],

Cell[BoxData["89.17537067204427`"], "Output",
 CellChangeTimes->{{3.465836106169139*^9, 3.465836125354309*^9}}]
}, Open  ]],

Cell[BoxData["\[IndentingNewLine]"], "Input",
 CellChangeTimes->{3.465835112296405*^9}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"994", " ", "nm", " ", 
   RowBox[{"(", 
    RowBox[{
    "to", " ", "be", " ", "doubled", " ", "to", " ", "497", " ", "nm"}], 
    ")"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465328140157063*^9, 3.465328141061544*^9}, {
  3.465833650613103*^9, 3.4658336853465147`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"10", "^", "6"}], "/", 
   RowBox[{"(", 
    RowBox[{"994", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "4"}], "]"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4658351222064*^9, 3.4658351229462147`*^9}},
 Background->RGBColor[1, 0, 0]],

Cell[BoxData["1422.7500627495926`"], "Output",
 CellChangeTimes->{3.4658351248893557`*^9},
 Background->RGBColor[1, 0, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"What", " ", "if", " ", "we", " ", "tried", " ", "1420", " ", 
   RowBox[{"g", "/", 
    RowBox[{"mm", "?"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465836135274007*^9, 3.465836163459231*^9}, 
   3.465836256142826*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"994", "*", 
     RowBox[{"1420", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465836171374789*^9, 3.465836198377952*^9}, {
  3.46583624977236*^9, 3.465836250658485*^9}},
 Background->RGBColor[1, 0, 0]],

Cell[BoxData["89.77871714481671`"], "Output",
 CellChangeTimes->{{3.465836176132292*^9, 3.465836198681267*^9}, 
   3.4658362518040247`*^9},
 Background->RGBColor[1, 0, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Best", " ", "catalog", " ", "option", " ", "offered", " ", "by", " ", 
   "Newport", " ", "is", " ", "1350", " ", 
   RowBox[{"g", "/", "mm"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.467997251286166*^9, 3.467997305549161*^9}, {
  3.468016476773144*^9, 3.468016477774732*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"994", "*", 
     RowBox[{"1350", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.467997394481451*^9, 3.4679973948692093`*^9}, {
  3.467997490379293*^9, 3.4679974919892263`*^9}, {3.4680164522470627`*^9, 
  3.4680164715665493`*^9}},
 Background->RGBColor[1, 0, 0]],

Cell[BoxData["84.28085732230063`"], "Output",
 CellChangeTimes->{
  3.467997396743566*^9, 3.467997493143507*^9, {3.468016453386598*^9, 
   3.468016472003159*^9}},
 Background->RGBColor[1, 0, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"922", " ", "nm", " ", 
    RowBox[{"(", 
     RowBox[{
     "to", " ", "be", " ", "doubled", " ", "to", " ", "461", " ", "nm"}], 
     ")"}]}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.4658351463239393`*^9, 3.465835154049317*^9}, 
   3.465835186087736*^9, 3.4658362740972633`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"10", "^", "6"}], "/", 
   RowBox[{"(", 
    RowBox[{"922", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "4"}], "]"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465835162336803*^9, 3.465835165593648*^9}, {
  3.465835197526475*^9, 3.465835208322401*^9}},
 Background->RGBColor[0, 1, 1]],

Cell[BoxData["1533.854189124832`"], "Output",
 CellChangeTimes->{3.465835166676324*^9, 3.465835214003564*^9},
 Background->RGBColor[0, 1, 1]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"What", " ", "if", " ", "we", " ", "tried", " ", "1540", " ", 
   RowBox[{"g", "/", 
    RowBox[{"mm", "?"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465836773275915*^9, 3.4658367744574623`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"922", "*", 
     RowBox[{"1540", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465836311870633*^9, 3.46583631464181*^9}, 
   3.465836778090785*^9, {3.465836980924798*^9, 3.465836994214293*^9}},
 Background->RGBColor[0, 1, 1]],

Cell[BoxData["90.46006754757607`"], "Output",
 CellChangeTimes->{3.465836315556059*^9, 3.4658367786298857`*^9, 
  3.4658369836151037`*^9, 3.465837045879675*^9},
 Background->RGBColor[0, 1, 1]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Best", " ", "catalog", " ", "option", " ", "offered", " ", "by", " ", 
   "Newport", " ", "is", " ", "1500", " ", 
   RowBox[{"g", "/", "mm"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.4679975056251698`*^9, 3.467997521517075*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"922", "*", 
     RowBox[{"1500", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.467997529586934*^9, 3.467997529821394*^9}},
 Background->RGBColor[0, 1, 1]],

Cell[BoxData["87.49792892560956`"], "Output",
 CellChangeTimes->{3.4679975307307997`*^9},
 Background->RGBColor[0, 1, 1]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"914", " ", "nm", " ", 
    RowBox[{"(", 
     RowBox[{"optical", " ", "lattice", " ", "laser"}], ")"}]}], " ", 
   "*)"}]}]], "Input",
 CellChangeTimes->{{3.465835173637947*^9, 3.465835174113055*^9}, {
   3.465835210897604*^9, 3.465835241033737*^9}, 3.46583634237683*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"10", "^", "6"}], "/", 
   RowBox[{"(", 
    RowBox[{"914", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "4"}], "]"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465835200774457*^9, 3.465835201057663*^9}},
 Background->RGBColor[0, 1, 0]],

Cell[BoxData["1547.279608723299`"], "Output",
 CellChangeTimes->{3.465835244691947*^9},
 Background->RGBColor[0, 1, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"What", " ", "if", " ", "we", " ", "tried", " ", "1540", " ", 
   RowBox[{"g", "/", 
    RowBox[{"mm", "?"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.465836594643454*^9, 3.4658365947695723`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"914", "*", 
     RowBox[{"1540", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465836563146656*^9, 3.46583656364189*^9}, {
   3.465836754157735*^9, 3.465836754220578*^9}, 3.465837003042677*^9, {
   3.4658370425428257`*^9, 3.465837042970368*^9}},
 Background->RGBColor[0, 1, 0]],

Cell[BoxData["89.462132370124`"], "Output",
 CellChangeTimes->{3.465836598726851*^9, 3.46583675566359*^9, 
  3.465837003958784*^9, 3.465837043553097*^9},
 Background->RGBColor[0, 1, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Best", " ", "catalog", " ", "option", " ", "is", " ", "again", " ", "1500",
    " ", 
   RowBox[{"g", "/", "mm"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.467997544766749*^9, 3.46799756136486*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"914", "*", 
     RowBox[{"1500", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.467997567506277*^9, 3.46799757412178*^9}},
 Background->RGBColor[0, 1, 0]],

Cell[BoxData["86.54988402192322`"], "Output",
 CellChangeTimes->{{3.46799757137919*^9, 3.4679975748952208`*^9}},
 Background->RGBColor[0, 1, 0]]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"689", " ", "nm", " ", 
     RowBox[{"(", 
      RowBox[{"secondary", " ", "trap", " ", 
       RowBox[{"laser", "/", "NARROW"}], " ", "linewidth"}], ")"}]}], " ", 
    "*)"}]}],
  FontColor->RGBColor[0, 1, 0]]], "Input",
 CellChangeTimes->{{3.465835257260151*^9, 3.465835294905106*^9}, 
   3.465836338867231*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"10", "^", "6"}], "/", 
   RowBox[{"(", 
    RowBox[{"689", "/", 
     RowBox[{"(", 
      RowBox[{"2", "*", 
       RowBox[{"Sin", "[", 
        RowBox[{"Pi", "/", "4"}], "]"}]}], ")"}]}], ")"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465835300123698*^9, 3.465835308081904*^9}},
 Background->RGBColor[1, 0.5, 0]],

Cell[BoxData["2052.559597058193`"], "Output",
 CellChangeTimes->{3.465835308828673*^9},
 Background->RGBColor[1, 0.5, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"What", " ", "if", " ", "we", " ", "tried", " ", "2050", " ", 
   RowBox[{"g", "/", 
    RowBox[{"mm", "?"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.4658371826767893`*^9, 3.465837183681974*^9}, 
   3.4658376118931007`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"689", "*", 
     RowBox[{"2050", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.465836862336413*^9, 3.4658368833541327`*^9}, 
   3.465837615075759*^9},
 Background->RGBColor[1, 0.5, 0]],

Cell[BoxData["89.85719019331427`"], "Output",
 CellChangeTimes->{3.4658366157160997`*^9, 3.4658368843873577`*^9, 
  3.465837616115095*^9},
 Background->RGBColor[1, 0.5, 0]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Best", " ", "catalog", " ", "option", " ", "is", " ", "2000", " ", 
   RowBox[{"g", "/", "mm"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.467997583264127*^9, 3.4679975936595488`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"2", "*", 
   RowBox[{"180", "/", "Pi"}], "*", 
   RowBox[{"ArcSin", "[", 
    RowBox[{"689", "*", 
     RowBox[{"2000", "/", 
      RowBox[{"(", 
       RowBox[{"2", "*", 
        RowBox[{"10", "^", "6"}]}], ")"}]}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4679976012069817`*^9, 3.467997601461419*^9}},
 Background->RGBColor[1, 0.5, 0]],

Cell[BoxData["87.10200448418627`"], "Output",
 CellChangeTimes->{3.4679976017795143`*^9},
 Background->RGBColor[1, 0.5, 0]]
}, Open  ]]
},
WindowSize->{640, 750},
WindowMargins->{{200, Automatic}, {Automatic, 0}},
FrontEndVersion->"6.0 for Mac OS X x86 (32-bit) (May 21, 2008)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[568, 21, 434, 9, 43, "Input"],
Cell[1005, 32, 694, 17, 43, "Input"],
Cell[1702, 51, 455, 12, 43, "Input"],
Cell[2160, 65, 525, 13, 27, "Input"],
Cell[2688, 80, 145, 2, 27, "Input"],
Cell[2836, 84, 305, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[3166, 96, 434, 12, 27, "Input"],
Cell[3603, 110, 88, 1, 27, "Output"]
}, Open  ]],
Cell[3706, 114, 507, 9, 43, "Input"],
Cell[CellGroupData[{
Cell[4238, 127, 547, 13, 27, "Input"],
Cell[4788, 142, 111, 1, 27, "Output"]
}, Open  ]],
Cell[4914, 146, 87, 1, 43, "Input"],
Cell[5004, 149, 325, 8, 27, "Input"],
Cell[CellGroupData[{
Cell[5354, 161, 369, 11, 43, "Input"],
Cell[5726, 174, 122, 2, 43, "Output"]
}, Open  ]],
Cell[5863, 179, 273, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[6161, 189, 435, 12, 43, "Input"],
Cell[6599, 203, 171, 3, 43, "Output"]
}, Open  ]],
Cell[6785, 209, 332, 7, 27, "Input"],
Cell[CellGroupData[{
Cell[7142, 220, 493, 13, 43, "Input"],
Cell[7638, 235, 194, 4, 43, "Output"]
}, Open  ]],
Cell[7847, 242, 390, 9, 58, "Input"],
Cell[CellGroupData[{
Cell[8262, 255, 418, 12, 43, "Input"],
Cell[8683, 269, 141, 2, 43, "Output"]
}, Open  ]],
Cell[8839, 274, 249, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[9113, 283, 458, 12, 43, "Input"],
Cell[9574, 297, 192, 3, 43, "Output"]
}, Open  ]],
Cell[9781, 303, 285, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[10091, 313, 387, 11, 43, "Input"],
Cell[10481, 326, 121, 2, 43, "Output"]
}, Open  ]],
Cell[10617, 331, 375, 8, 58, "Input"],
Cell[CellGroupData[{
Cell[11017, 343, 369, 11, 43, "Input"],
Cell[11389, 356, 119, 2, 43, "Output"]
}, Open  ]],
Cell[11523, 361, 249, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[11797, 370, 510, 13, 43, "Input"],
Cell[12310, 385, 185, 3, 43, "Output"]
}, Open  ]],
Cell[12510, 391, 253, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[12788, 401, 386, 11, 43, "Input"],
Cell[13177, 414, 144, 2, 43, "Output"]
}, Open  ]],
Cell[13336, 419, 430, 11, 58, "Input"],
Cell[CellGroupData[{
Cell[13791, 434, 371, 11, 43, "Input"],
Cell[14165, 447, 121, 2, 43, "Output"]
}, Open  ]],
Cell[14301, 452, 277, 6, 27, "Input"],
Cell[CellGroupData[{
Cell[14603, 462, 417, 12, 43, "Input"],
Cell[15023, 476, 172, 3, 43, "Output"]
}, Open  ]],
Cell[15210, 482, 238, 5, 27, "Input"],
Cell[CellGroupData[{
Cell[15473, 491, 391, 11, 43, "Input"],
Cell[15867, 504, 123, 2, 43, "Output"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
